// --------------------------------------------------------------------------
// multiTrigger.h - C++ Header File
// --------------------------------------------------------------------------
// Copyright 2004 Michael B. Comet  All Rights Reserved
// --------------------------------------------------------------------------
//
// DESCRIPTION:
//	Header for multiTrigger node.
//
// AUTHORS:
//		Michael B. Comet - comet@comet-cartoons.com
//
// VERSIONS:
//		1.09 - 11/17/04 - comet - Has multiTrigger support for better usage
//				of multiple nodes at once.  Also has allowRotate option.
//		1.10 - 01/21/05 - mcomet - Now has nodestate HasNoEffect stop.
//
// --------------------------------------------------------------------------
//
//  multiTrigger - Pose Space Value Trigger Maya Plugin by Michael B. Comet
//  Copyright 2004 Michael B. Comet
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//   For information on poseDeformer contact:
//			Michael B. Comet - comet@comet-cartoons.com
//			or visit http://www.comet-cartooons.com/toons/
//
// --------------------------------------------------------------------------

#ifndef _multiTriggerNode
#define _multiTriggerNode

/*
 * Includes
 */
#include <maya/MGlobal.h>
#include <maya/MPxNode.h>
#include <maya/MTypeId.h> 


typedef enum { eTriggerLowest, eTriggerAverage, eTriggerMultiply } ETRIGGERMODE ;

// --------------------------------------------------------------------------

/*
 * multiTrigger - Class definition for main pose calc node
 */
class multiTrigger : public MPxNode
{
public:
						multiTrigger();
	virtual				~multiTrigger(); 

	virtual MStatus		compute( const MPlug& plug, MDataBlock& data );

	static  void*		creator();
	static  MStatus		initialize();

	static	MTypeId		id;

public:
	// Input Attrs
	static MObject		aInput ;				// Cmpd Inputs
	static MObject		aEnvelope ;				// Basic overall envelope
	static MObject		aTriggerMode ;			// How are we triggering output value?
	static MObject		aInputValues ;			// Array of input values 

	// Output Attrs
	static MObject		aOutWeight ;			// Output weight

private:
	MStatus readInputValues(MDataBlock &data, MDoubleArray &dArrVals, unsigned &uVals) ;

};

#endif

// --------------------------------------------------------------------------
